@@ -6,14 +6,12 @@
 
 import inspect
 import json
-import traceback
 from typing import Optional, Awaitable
 
 from bson import ObjectId
 from tornado import httputil
 from tornado.ioloop import IOLoop
-from tornado.web import RequestHandler
-
+from tornado.web import RequestHandler, Application
 from lesscode.web.status_code import StatusCode
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.response_result import ResponseResult
@@ -85,24 +83,50 @@ class BaseHandler(RequestHandler):
                             continue
                         else:
                             # 如果没有有默认值，要抛出异常 提示"请求缺少必要参数"
-                            raise BusinessException(StatusCode.MESSAGE_FORMAT(StatusCode.REQUIRED_PARAM_IS_EMPTY,
-                                                                              parameter_name))
-                    elif isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
+                            raise BusinessException(StatusCode.REQUIRED_PARAM_IS_EMPTY(parameter_name))
+                    # 获取形参类型
+                    parameter_type = parameter.annotation
+                    # 形参类型为空，尝试获取形参默认值类型
+                    if parameter_type is inspect.Parameter.empty:
+                        if parameter.default is inspect.Parameter.empty:
+                            parameter_type = type(parameter.default)
+                        else:
+                            parameter_type = type(parameter.default)
+                    # new_value = parse_val(argument_value, parameter_type)
+                    # params_list.append(new_value)
+                    # # 获取实参类型
+                    # argument_type = type(argument_value)
+                    if isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
                         # 仅一个 直接存入
                         if len(argument_value) == 1:
-                            params_list.append(argument_value[0].decode())
+                            params_list.append(parse_val(argument_value[0], parameter_type))
                         else:  # 多个要使用集合存入
-                            params_list.append([v.decode() for v in argument_value])
-                    else:
-                        # 其他类型的直接存入
-                        params_list.append(argument_value)
+                            params_list.append([parse_val(v, parameter_type) for v in argument_value])
+                    # print(f"parameter_name:{parameter_name},parameter_type:{parameter_type},argument_type:{argument_type}")
+                    # new_value = parse_val(argument_value,)
+                    # elif isinstance(argument_value, list):  # 如果参数是集合类型要进行遍历并进行转码
+                    #     # 仅一个 直接存入
+                    #     if len(argument_value) == 1:
+                    #         params_list.append(argument_value[0].decode())
+                    #     else:  # 多个要使用集合存入
+                    #         params_list.append([v.decode() for v in argument_value])
+                    # else:
+                    #     # 其他类型的直接存入
+                    #     params_list.append(argument_value)
+                    # val_type = type(args.get(func_params[i], None))
+                    # if func_params[i] in params.keys():
+                    #     val = params.get(func_params[i])
+                    #     if not is_json:
+                    #         val = parse_val(val, val_type)
+                    #     params_list.append(val)
+
             # 判断是否为异步非阻塞方法，true 则直接调用
             if inspect.iscoroutinefunction(handler_method):
                 data = await handler_method(*params_list)
             else:
                 # 阻塞方法异步调用
                 data = await IOLoop.current().run_in_executor(None, handler_method, *params_list)
-            self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False,cls=JSONEncoder))
+            self.write(json.dumps(ResponseResult(data=data), ensure_ascii=False, cls=JSONEncoder))
         else:
             raise BusinessException(StatusCode.RESOURCE_NOT_FOUND)
 
@@ -143,8 +167,7 @@ class BaseHandler(RequestHandler):
         else:
             # for line in traceback.format_exception(*kwargs["exc_info"]):
             #     self.write(line)
-            self.write(json.dumps(ResponseResult(StatusCode.MESSAGE_FORMAT(StatusCode.INTERNAL_SERVER_ERROR,
-                                                                           error[1])), ensure_ascii=False))
+            self.write(json.dumps(ResponseResult(StatusCode.INTERNAL_SERVER_ERROR(error[1])), ensure_ascii=False))
         self.finish()
 
     def _request_summary(self):
@@ -161,4 +184,32 @@ class JSONEncoder(json.JSONEncoder):
     def default(self, o):
         if isinstance(o, ObjectId):
             return str(o)
-        return json.JSONEncoder.default(self, o)
\ No newline at end of file
+        return json.JSONEncoder.default(self, o)
+
+
+# 解析param
+def parse_val(val, val_type):
+    # inspect.Parameter.empty <class 'NoneType'>
+    # isinstance(parameter.annotation, )
+    new_val = val
+    if isinstance(val, bytes) or isinstance(val, bytearray):
+        new_val = val.decode("utf-8")
+    if isinstance(val, list):
+        val_list = []
+        for item in val:
+            val_item = parse_val(item, None)
+            val_list.append(val_item)
+        if val_type == list:
+            return val_list
+        else:
+            new_val = val_list
+    if type(new_val) != val_type:
+        if val_type == int:
+            return int(new_val)
+        elif val_type == str and isinstance(new_val, list):
+            return new_val[0]
+        elif val_type == dict:
+            return json.loads(new_val)
+        else:
+            return new_val
+    return new_val
