@@ -15,7 +15,11 @@ class StatusCode:
     # C表示错误来源于第三方服务
     """
 
+    def __init__(self, message=None):
+        self.message = message
+
     # *响应服务请求的状态码与说明
+
     SUCCESS = ("00000", "请求成功")
     FAIL = ("99999", "请求失败")
     USER_VALIDATE_FAIL = ("A0001", "用户端错误")
@@ -31,7 +35,17 @@ class StatusCode:
     USER_ACCOUNT_NOT_EXIST = ("A0201", "用户账户不存在")
     REQUEST_PARAM_ERROR = ("A0300", "用户请求参数错误")
     INVALID_USER_INPUT = ("A0301", "无效的用户输入")
-    REQUIRED_PARAM_IS_EMPTY = ("A0310", "请求缺少必要参数:{}")
+
+    # REQUIRED_PARAM_IS_EMPTY = ("A0310", "请求缺少必要参数:{}")
+    @staticmethod
+    def REQUIRED_PARAM_IS_EMPTY(message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0310", "请求缺少必要参数:{}".format(message)
+
     INVALID_TIME_STAMP = ("A0311", "非法的时间戳参数")
     USER_INPUT_INVALID = ("A0312", "用户输入内容非法")
     VALIDATE_CODE_EXPIRE = ("A0400", "验证码过期")
@@ -40,25 +54,44 @@ class StatusCode:
     PARAM_BIND_FAIL = ("A0403", "参数绑定失败")
     PHONE_NUM_NOT_FOUND = ("A0404", "找不到该用户，手机号码有误")
     PHONE_ALREADY_REGISTER = ("A0405", "手机号已经注册")
-    BUSINESS_FAIL = ("B0000", "{}")
+
+    # BUSINESS_FAIL = ("B0000", "{}")
+    @staticmethod
+    def BUSINESS_FAIL(message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "B0000", "{}".format(message)
+
     ACCESS_DENIED = ("B0001", "访问权限不足")
     RESOURCE_DISABLED = ("B0002", "资源被禁用")
     RESOURCE_NO_AUTHORITY = ("B0003", "该资源未定义访问权限")
     RESOURCE_NOT_FOUND = ("B0404", "访问资源不存在")
-    INTERNAL_SERVER_ERROR = ("B0500", "服务器内部错误:{}")
-    RESOURCE_EXIST = ("B0501", "{}已存在,确保唯一性，不可重复")
+    # INTERNAL_SERVER_ERROR = ("B0500", "服务器内部错误:{}")
+
+    @staticmethod
+    def INTERNAL_SERVER_ERROR(message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "B0500", "服务器内部错误:{}".format(message)
+
+    # RESOURCE_EXIST = ("B0501", "{}已存在,确保唯一性，不可重复")
+    @staticmethod
+    def RESOURCE_EXIST(message):
+        """
+        用于自定义消息提示信息
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "B0501", "{}已存在,确保唯一性，不可重复".format(message)
     TIMEOUT = ("B0100", "系统执行超时")
     STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
     RPC_INVOKE_ERROR = ("C0001", "调用第三方服务出错")
     SERVER_ERROR = ("C0002", "服务器内部错误")
     UNKNOWN_ERROR = ("C0003", "未知异常")
 
-    @staticmethod
-    def MESSAGE_FORMAT(status_code: Tuple[str, str], message):
-        """
-        用于自定义消息提示信息
-        :param status_code: 状态码元祖
-        :param message: 替换的消息内容
-        :return:
-        """
-        return status_code[0], status_code[1].format(message)
